hydra\_zen.BuildsFn
===================

.. currentmodule:: hydra_zen

.. autoclass:: BuildsFn

   
   .. automethod:: _sanitized_type
   .. automethod:: _make_hydra_compatible
   .. automethod:: _get_obj_path

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BuildsFn._sanitized_type
      ~BuildsFn._make_hydra_compatible
      ~BuildsFn._get_obj_path

